@@ -2,9 +2,9 @@ from .LedDev import LedDev
 from .DebugLedDev import DebugLedDev
 try:
     from .NeopixelDev import NeopixelDev
-except ImportError:
+except (ImportError, NotImplementedError):
     pass
 try:
-    from .GPIODev import GPIODev
+    from .I2CPixelDev import I2CPixelDev
 except ImportError:
     pass
